@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Email::Simple::Header;
 # ABSTRACT: the header of an Email::Simple message
-$Email::Simple::Header::VERSION = '2.206';
+$Email::Simple::Header::VERSION = '2.210';
 use Carp ();
 
 require Email::Simple;
@@ -316,15 +316,21 @@ sub _fold {
 
   my $indent = $arg->{indent} || $self->_default_fold_indent;
 
+  return $self->__fold_objless($line, $limit, $indent, $self->crlf);
+}
+
+sub __fold_objless {
+  my ($self, $line, $limit, $indent, $crlf) = @_;
+
   # We know it will not contain any new lines at present
   my $folded = "";
-  while ($line) {
+  while (length $line) {
     if ($line =~ s/^(.{0,$limit})(\s|\z)//) {
-      $folded .= $1 . $self->crlf;
-      $folded .= $indent if $line;
+      $folded .= $1 . $crlf;
+      $folded .= $indent if length $line;
     } else {
       # Basically nothing we can do. :(
-      $folded .= $line . $self->crlf;
+      $folded .= $line . $crlf;
       last;
     }
   }
@@ -364,7 +370,7 @@ Email::Simple::Header - the header of an Email::Simple message
 
 =head1 VERSION
 
-version 2.206
+version 2.210
 
 =head1 SYNOPSIS
 
